@@ -18,7 +18,7 @@ class ComboBoxEditArgs(CommonParameterWidgetArgs):
 
 
 class ComboBoxEdit(CommonParameterWidget):
-    HIDE_DEFAULT_WIDGET = True
+    HIDE_DEFAULT_VALUE_WIDGET = True
     SET_DEFAULT_ON_INIT = True
 
     _WidgetArgsClass = ComboBoxEditArgs
